package HTML::EasyForm::Field::Text;
BEGIN {
  $HTML::EasyForm::Field::Text::AUTHORITY = 'cpan:GETTY';
}
BEGIN {
  $HTML::EasyForm::Field::Text::VERSION = '0.101';
}
# ABSTRACT: Text field

use Moose;
extends 'HTML::EasyForm::Field';

1;
__END__
=pod

=head1 NAME

HTML::EasyForm::Field::Text - Text field

=head1 VERSION

version 0.101

=head1 AUTHOR

Torsten Raudssus <torsten@raudssus.de>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

